@@ -2,7 +2,7 @@ import logging
 from os import getcwd
 from os.path import dirname
 
-__version__ = '0.3.15'
+__version__ = '0.3.25'
 basedir = dirname(__file__)
 
 # create logger
@@ -15,6 +15,10 @@ console_handler.setFormatter(formatter)
 logger.addHandler(console_handler)
 
 
+class SonusAIError(Exception):
+    pass
+
+
 # create file handler
 def create_file_handler(filename: str):
     fh = logging.FileHandler(filename=filename, mode='w')
@@ -37,9 +41,9 @@ def initial_log_messages(name: str):
     from getpass import getuser
     from socket import gethostname
 
-    logger.info('SonusAI {} {}'.format(name, __version__))
-    logger.debug('Host:      {}'.format(gethostname()))
-    logger.debug('User:      {}'.format(getuser()))
-    logger.debug('Directory: {}'.format(getcwd()))
-    logger.debug('Date:      {}'.format(datetime.now()))
+    logger.info(f'SonusAI {name} {__version__}')
+    logger.debug(f'Host:      {gethostname()}')
+    logger.debug(f'User:      {getuser()}')
+    logger.debug(f'Directory: {getcwd()}')
+    logger.debug(f'Date:      {datetime.now()}')
     logger.debug('')
