@@ -118,8 +118,8 @@ will find all .wav files in the specified directories and process them as target
 """
 import json
 import re
+import time
 from copy import deepcopy
-from functools import partial
 from glob import glob
 from numbers import Number
 from os import listdir
@@ -135,28 +135,31 @@ import numpy as np
 import sox
 import yaml
 from docopt import docopt
-from p_tqdm import p_map
 from pyaaware import FeatureGenerator
+from tqdm import tqdm
 
 import sonusai
+from sonusai import SonusAIError
 from sonusai import create_file_handler
 from sonusai import initial_log_messages
 from sonusai import logger
 from sonusai import update_console_handler
 from sonusai.mixture import apply_augmentation
 from sonusai.mixture import estimate_audio_length
-from sonusai.mixture import get_class_count
+from sonusai.mixture import generate_truth
 from sonusai.mixture import get_class_weights_threshold
 from sonusai.mixture import get_config_from_file
 from sonusai.mixture import get_next_noise
 from sonusai.mixture import get_total_class_count
 from sonusai.mixture import read_audio
-from sonusai.mixture import truth_function
 from sonusai.utils import expandvars
 from sonusai.utils import human_readable_size
+from sonusai.utils import p_map
 from sonusai.utils import seconds_to_hms
 from sonusai.utils import trim_docstring
 
+genmixdb_global = dict()
+
 
 def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) -> dict:
     required_keys = [
@@ -179,13 +182,13 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
     ]
     for key in required_keys:
         if key not in config.keys():
-            logger.error('Missing {} in config'.format(key))
-            exit()
+            logger.exception(f'Missing {key} in config')
+            raise SonusAIError
 
     seed(config['seed'])
 
     if logging:
-        logger.debug('Seed: {}'.format(config['seed']))
+        logger.debug(f'Seed: {config["seed"]}')
         logger.debug('Configuration:')
         logger.debug(yaml.dump(config))
 
@@ -195,8 +198,8 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
                                                       'truth_function': config['truth_function'],
                                                       'truth_config':   config['truth_config']})
     if len(targets) == 0:
-        logger.error('Canceled due to no targets')
-        exit()
+        logger.exception('Canceled due to no targets')
+        raise SonusAIError
 
     if logging:
         logger.debug('List of targets:')
@@ -207,7 +210,7 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
     noises = get_input_files(config['noises'])
     if len(noises) == 0:
         if logging:
-            logger.warning('Did not find any noises; using default noise: {}'.format(sonusai.mixture.default_noise))
+            logger.warning(f'Did not find any noises; using default noise: {sonusai.mixture.default_noise}')
         noises = get_input_files([sonusai.mixture.default_noise])
     if logging:
         logger.debug('List of noises:')
@@ -218,7 +221,7 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
     target_augmentations = get_augmentations(config['target_augmentations'], target=True)
     expanded_target_augmentations = ''
     for augmentation in target_augmentations:
-        expanded_target_augmentations += '- {}\n'.format(augmentation)
+        expanded_target_augmentations += f'- {augmentation}\n'
     if logging:
         logger.debug('Expanded list of target augmentations:')
         logger.debug(expanded_target_augmentations)
@@ -228,7 +231,7 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
     noise_augmentations = get_augmentations(config['noise_augmentations'], target=False)
     expanded_noise_augmentations = ''
     for augmentation in noise_augmentations:
-        expanded_noise_augmentations += '- {}\n'.format(augmentation)
+        expanded_noise_augmentations += f'- {augmentation}\n'
     if logging:
         logger.debug('Expanded list of noise augmentations:')
         logger.debug(expanded_noise_augmentations)
@@ -238,13 +241,13 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
     total_mixtures = noise_sets * target_sets
     if logging:
         logger.info('')
-        logger.info('Found {} mixtures to process'.format(total_mixtures))
+        logger.info(f'Found {total_mixtures} mixtures to process')
 
     class_weights_threshold = get_class_weights_threshold(config)
 
     if config['truth_mode'] not in ['normal', 'mutex']:
-        logger.error('invalid truth_mode: {}'.format(config['truth_mode']))
-        exit()
+        logger.exception(f'invalid truth_mode: {config["truth_mode"]}')
+        raise SonusAIError
 
     truth_mutex = config['truth_mode'] == 'mutex'
     if truth_mutex:
@@ -283,30 +286,31 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
 
     mixture_bytes = total_samples * sonusai.mixture.bit_depth / 8
     truth_t_bytes = total_samples * config['num_classes'] * sonusai.mixture.float_bytes
-    feature_bytes = total_samples / feature_samples * stride * num_bands * sonusai.mixture.float_bytes
-    truth_f_bytes = total_samples / feature_samples * config['num_classes'] * sonusai.mixture.float_bytes
+    feature_bytes = total_samples / feature_step_samples * stride * num_bands * sonusai.mixture.float_bytes
+    truth_f_bytes = total_samples / feature_step_samples * config['num_classes'] * sonusai.mixture.float_bytes
 
     if logging:
         logger.info('')
-        logger.info('Estimated duration:   {}'.format(seconds_to_hms(seconds=total_duration)))
+        logger.info(f'Estimated duration:   {seconds_to_hms(seconds=total_duration)}')
         logger.info('Estimated sizes:')
-        logger.info(' mixture:             {}'.format(human_readable_size(mixture_bytes, 1)))
-        logger.info(' truth_t:             {}'.format(human_readable_size(truth_t_bytes, 1)))
-        logger.info(' feature:             {}'.format(human_readable_size(feature_bytes, 1)))
-        logger.info(' truth_f:             {}'.format(human_readable_size(truth_f_bytes, 1)))
-        logger.info('Feature shape:        {} x {} ({} total params)'.format(stride, num_bands, stride * num_bands))
-        logger.info('Feature samples:      {} samples ({} ms)'.format(feature_samples, feature_ms))
-        logger.info('Feature step samples: {} samples ({} ms)'.format(feature_step_samples, feature_step_ms))
+        logger.info(f' mixture:             {human_readable_size(mixture_bytes, 1)}')
+        logger.info(f' truth_t:             {human_readable_size(truth_t_bytes, 1)}')
+        logger.info(f' feature:             {human_readable_size(feature_bytes, 1)}')
+        logger.info(f' truth_f:             {human_readable_size(truth_f_bytes, 1)}')
+        logger.info(f'Feature shape:        {stride} x {num_bands} ({stride * num_bands} total params)')
+        logger.info(f'Feature samples:      {feature_samples} samples ({feature_ms} ms)')
+        logger.info(f'Feature step samples: {feature_step_samples} samples ({feature_step_ms} ms)')
 
     mixdb = {
-        'class_count':              [],
+        'class_count':              list(),
         'class_labels':             config['class_labels'],
         'class_weights_threshold':  list(class_weights_threshold),
         'dither':                   config['dither'],
         'feature':                  config['feature'],
+        'feature_samples':          feature_samples,
         'feature_step_samples':     feature_step_samples,
         'frame_size':               config['frame_size'],
-        'mixtures':                 [],
+        'mixtures':                 list(),
         'noise_augmentations':      noise_augmentations,
         'noises':                   noises,
         'num_classes':              config['num_classes'],
@@ -319,22 +323,22 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
     # Read in all audio data beforehand to avoid reading it multiple times in the loop
     if logging:
         logger.debug('Reading noise audio')
-    raw_noise_audio = []
+    raw_noise_audio = list()
     for noise in noises:
         raw_noise_audio.append(read_audio(name=noise['name'], dither=config['dither']))
 
     if logging:
         logger.debug('Reading target audio')
-    raw_target_audio = []
+    raw_target_audio = list()
     for target in targets:
         raw_target_audio.append(read_audio(name=target['name'], dither=config['dither']))
 
     # First pass to get indices and offsets
-    mixtures = [[] for n in range(noise_sets)]
+    mixtures = [[] for _ in range(noise_sets)]
     n_id = 0
     for noise_index, noise in enumerate(noises):
         for noise_augmentation_index, noise_augmentation in enumerate(noise_augmentations):
-            mixtures[n_id] = [[] for n in range(target_sets)]
+            mixtures[n_id] = [[] for _ in range(target_sets)]
             t_id = 0
             noise_offset = 0
             noise_length = estimate_audio_length(audio_in=raw_noise_audio[noise_index],
@@ -342,12 +346,22 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
                                                  length_common_denominator=1)
             for target_index, target in enumerate(targets):
                 for target_augmentation_index, target_augmentation in enumerate(target_augmentations):
+                    if not isinstance(target['truth_function'], list):
+                        target['truth_function'] = [target['truth_function']]
+
                     if not isinstance(target['truth_index'], list):
                         target['truth_index'] = [target['truth_index']]
 
-                    if any(i > max_class for i in target['truth_index']):
-                        logger.error('invalid truth_index')
-                        exit()
+                    if len(target['truth_function']) != len(target['truth_index']):
+                        logger.exception('length of truth_index does not match length of truth_function')
+                        raise SonusAIError
+
+                    for i in range(len(target['truth_function'])):
+                        if not isinstance(target['truth_index'][i], list):
+                            target['truth_index'][i] = [target['truth_index'][i]]
+                        if any(idx > max_class for idx in target['truth_index'][i]):
+                            logger.exception('invalid truth_index')
+                            raise SonusAIError
 
                     mixtures[n_id][t_id] = {'target_file_index':         target_index,
                                             'noise_file_index':          noise_index,
@@ -363,27 +377,24 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
 
             n_id += 1
 
+    genmixdb_global['mixdb'] = mixdb
+    genmixdb_global['config'] = config
+    genmixdb_global['target_augmentations'] = target_augmentations
+    genmixdb_global['raw_target_audio'] = raw_target_audio
+    genmixdb_global['feature_step_samples'] = feature_step_samples
+
+    progress = tqdm(total=total_mixtures, desc='genmixdb', disable=not show_progress)
+
     # Second pass to fill in the details
     for n_id in range(len(mixtures)):
-        augmented_noise_audio = apply_augmentation(
+        genmixdb_global['augmented_noise_audio'] = apply_augmentation(
             audio_in=raw_noise_audio[mixtures[n_id][0]['noise_file_index']],
             augmentation=noise_augmentations[mixtures[n_id][0]['noise_augmentation_index']],
             length_common_denominator=1,
             dither=config['dither'])
+        mixtures[n_id] = p_map(process_mixture, mixtures[n_id], progress=progress)
 
-        desc = 'genmixdb {} of {}'.format(n_id + 1, len(mixtures))
-        mixtures[n_id] = p_map(partial(process_mixture,
-                                       config=config,
-                                       targets=targets,
-                                       target_augmentations=target_augmentations,
-                                       raw_target_audio=raw_target_audio,
-                                       augmented_noise_audio=augmented_noise_audio,
-                                       feature_step_samples=feature_step_samples,
-                                       truth_mutex=truth_mutex,
-                                       class_weights_threshold=class_weights_threshold),
-                               mixtures[n_id],
-                               desc=desc,
-                               disable=not show_progress)
+    progress.close()
 
     # Flatten mixtures
     mixdb['mixtures'] = [item for sublist in mixtures for item in sublist]
@@ -393,25 +404,25 @@ def genmixdb(config: dict, logging: bool = True, show_progress: bool = False) ->
     total_duration = total_samples / sonusai.mixture.sample_rate
     mixture_bytes = total_samples * sonusai.mixture.bit_depth / 8
     truth_t_bytes = total_samples * config['num_classes'] * 4
-    feature_bytes = total_samples / feature_samples * stride * num_bands * 4
-    truth_f_bytes = total_samples / feature_samples * config['num_classes'] * 4
+    feature_bytes = total_samples / feature_step_samples * stride * num_bands * 4
+    truth_f_bytes = total_samples / feature_step_samples * config['num_classes'] * 4
     if logging:
         logger.info('')
-        logger.info('Actual duration: {}'.format(seconds_to_hms(seconds=total_duration)))
+        logger.info(f'Actual duration: {seconds_to_hms(seconds=total_duration)}')
         logger.info('Actual sizes:')
-        logger.info(' mixture:        {}'.format(human_readable_size(mixture_bytes, 1)))
-        logger.info(' truth_t:        {}'.format(human_readable_size(truth_t_bytes, 1)))
-        logger.info(' feature:        {}'.format(human_readable_size(feature_bytes, 1)))
-        logger.info(' truth_f:        {}'.format(human_readable_size(truth_f_bytes, 1)))
+        logger.info(f' mixture:        {human_readable_size(mixture_bytes, 1)}')
+        logger.info(f' truth_t:        {human_readable_size(truth_t_bytes, 1)}')
+        logger.info(f' feature:        {human_readable_size(feature_bytes, 1)}')
+        logger.info(f' truth_f:        {human_readable_size(truth_f_bytes, 1)}')
 
     return mixdb
 
 
 def get_input_files(records, cfg=None):
     if cfg is None:
-        cfg = {}
+        cfg = dict()
 
-    files = []
+    files = list()
     for record in records:
         append_input_files(files, record, cfg)
     return files
@@ -419,15 +430,15 @@ def get_input_files(records, cfg=None):
 
 def append_input_files(files: list, in_record, cfg: dict, tokens=None):
     if tokens is None:
-        tokens = {}
+        tokens = dict()
     in_name = in_record
 
     if isinstance(in_record, dict):
         if 'target_name' in in_record.keys():
             in_name = in_record['target_name']
         else:
-            logger.error('Target list contained record without \'target_name\' key')
-            exit()
+            logger.exception('Target list contained record without \'target_name\' key')
+            raise SonusAIError
 
         if 'truth_index' in in_record.keys():
             cfg['truth_index'] = in_record['truth_index']
@@ -442,8 +453,8 @@ def append_input_files(files: list, in_record, cfg: dict, tokens=None):
     tokens.update(new_tokens)
     names = glob(in_name)
     if not names:
-        logger.error('Could not find {}. Make sure path exists'.format(in_name))
-        exit()
+        logger.exception(f'Could not find {in_name}. Make sure path exists')
+        raise SonusAIError
     for name in names:
         ext = splitext(name)[1].lower()
         dir_name = dirname(name)
@@ -476,23 +487,27 @@ def append_input_files(files: list, in_record, cfg: dict, tokens=None):
                             for record in yml_config['targets']:
                                 append_input_files(files, record, cfg, tokens)
                     except Exception as e:
-                        logger.error('Error processing {}: {}'.format(name, e))
-                        exit()
+                        logger.exception(f'Error processing {name}: {e}')
+                        raise SonusAIError
                 else:
                     sox.file_info.validate_input_file(name)
                     duration = sox.file_info.duration(name)
                     for key, value in tokens.items():
-                        name = name.replace(value, '${}'.format(key))
+                        name = name.replace(value, f'${key}')
                     entry = {'name': name, 'duration': duration}
                     entry.update(cfg)
+                    if 'truth_function' in entry.keys() and entry['truth_function'] == 'file':
+                        entry['truth_config']['file'] = splitext(name)[0] + '.h5'
                     files.append(entry)
+            except SonusAIError:
+                raise
             except Exception as e:
-                logger.error('Error processing {}: {}'.format(name, e))
-                exit()
+                logger.exception(f'Error processing {name}: {e}')
+                raise SonusAIError
 
 
 def get_augmentations(rules: list, target: bool) -> list:
-    augmentations = []
+    augmentations = list()
     for rule in rules:
         expand_augmentations(augmentations, rule, target)
 
@@ -506,8 +521,8 @@ def expand_augmentations(augmentations: list, rule: dict, target: bool):
 
     for key in rule:
         if key not in sonusai.mixture.valid_augmentations:
-            logger.error('Invalid augmentation: {}'.format(key))
-            exit()
+            logger.exception(f'Invalid augmentation: {key}')
+            raise SonusAIError
 
         if key in ['eq1', 'eq2', 'eq3']:
             # eq must be a list of length 3 or a list of length 3 lists
@@ -526,8 +541,8 @@ def expand_augmentations(augmentations: list, rule: dict, target: bool):
                 valid = False
 
             if not valid:
-                logger.error('Invalid augmentation value for {}: {}'.format(key, rule[key]))
-                exit()
+                logger.exception(f'Invalid augmentation value for {key}: {rule[key]}')
+                raise SonusAIError
 
             if multiple:
                 for value in rule[key]:
@@ -543,16 +558,16 @@ def expand_augmentations(augmentations: list, rule: dict, target: bool):
             if isinstance(rule[key], list):
                 for value in rule[key]:
                     if isinstance(value, list):
-                        logger.error('Invalid augmentation value for {}: {}'.format(key, rule[key]))
-                        exit()
+                        logger.exception(f'Invalid augmentation value for {key}: {rule[key]}')
+                        raise SonusAIError
                     expanded_rule = deepcopy(rule)
                     expanded_rule[key] = deepcopy(value)
                     expand_augmentations(augmentations, expanded_rule, target)
                 return
             elif not isinstance(rule[key], Number):
                 if not rule[key].startswith('rand'):
-                    logger.error('Invalid augmentation value for {}: {}'.format(key, rule[key]))
-                    exit()
+                    logger.exception(f'Invalid augmentation value for {key}: {rule[key]}')
+                    raise SonusAIError
 
     # Set default snr for target if needed
     if target and 'snr' not in rule:
@@ -566,11 +581,11 @@ def expand_augmentations(augmentations: list, rule: dict, target: bool):
 
 
 def rand_repl(m):
-    return '{:.2f}'.format(uniform(float(m.group(1)), float(m.group(4))))
+    return f'{uniform(float(m.group(1)), float(m.group(4))):.2f}'
 
 
 def rand_augmentations(in_rules):
-    out_rules = []
+    out_rules = list()
     for rule in in_rules:
         # do any keys contain rand?
         has_rand = False
@@ -607,35 +622,25 @@ def get_base_name(config: dict, config_name: str) -> str:
         name = name.replace('${config}', config_base)
         return name
     except Exception as e:
-        logger.error('Error getting genmixdb base name: {}'.format(e))
-        exit()
+        logger.exception(f'Error getting genmixdb base name: {e}')
+        raise SonusAIError
 
 
-def process_mixture(mixture: dict,
-                    config: dict,
-                    targets: list,
-                    target_augmentations: list,
-                    raw_target_audio: list,
-                    augmented_noise_audio: np.ndarray,
-                    feature_step_samples: int,
-                    truth_mutex: bool,
-                    class_weights_threshold: list) -> dict:
+def process_mixture(mixture: dict) -> dict:
     target_index = mixture['target_file_index']
     noise_offset = mixture['noise_offset']
     target_augmentation_index = mixture['target_augmentation_index']
 
-    target = targets[target_index]
+    target_augmentation = genmixdb_global['target_augmentations'][target_augmentation_index]
 
-    target_augmentation = target_augmentations[target_augmentation_index]
-
-    augmented_target_audio = apply_augmentation(audio_in=raw_target_audio[target_index],
+    augmented_target_audio = apply_augmentation(audio_in=genmixdb_global['raw_target_audio'][target_index],
                                                 augmentation=target_augmentation,
-                                                length_common_denominator=feature_step_samples,
-                                                dither=config['dither'])
+                                                length_common_denominator=genmixdb_global['feature_step_samples'],
+                                                dither=genmixdb_global['config']['dither'])
 
     noise_segment, _ = get_next_noise(offset_in=noise_offset,
                                       length=len(augmented_target_audio),
-                                      audio_in=augmented_noise_audio)
+                                      audio_in=genmixdb_global['augmented_noise_audio'])
 
     # target_gain is the sum of 'gain', noise overflow adjustment, and mixture
     # overflow adjustment. It is used to return the target audio to its normalized
@@ -668,8 +673,9 @@ def process_mixture(mixture: dict,
                 mixture['noise_snr_gain'] = noise_gain
 
     # Check for clipping in mixture
-    mixture_audio = np.single(augmented_target_audio) * mixture['target_snr_gain'] + \
-                    np.single(noise_segment) * mixture['noise_snr_gain']
+    gain_adjusted_target_audio = np.single(augmented_target_audio) * mixture['target_snr_gain']
+    gain_adjusted_noise_audio = np.single(noise_segment) * mixture['noise_snr_gain']
+    mixture_audio = gain_adjusted_target_audio + gain_adjusted_noise_audio
 
     if any(abs(mixture_audio) >= 32768):
         # Clipping occurred; lower gains to bring audio within int16 bounds
@@ -678,30 +684,16 @@ def process_mixture(mixture: dict,
         mixture['noise_snr_gain'] *= gain_adjustment
         target_gain *= gain_adjustment
 
-    truth_config = deepcopy(target['truth_config'])
-    truth_config['index'] = target['truth_index']
-    truth_config['frame_size'] = config['frame_size']
-    truth_config['num_classes'] = config['num_classes']
-    truth_config['mutex'] = truth_mutex
-
-    if target_gain == 0:
-        truth = np.zeros((config['num_classes'], len(augmented_target_audio)), dtype=np.int16)
-    else:
-        augmented_target_audio = np.int16(
-            np.single(augmented_target_audio) * mixture['target_snr_gain'])
-        truth = truth_function(
-            audio=np.int16(np.single(augmented_target_audio) / target_gain),
-            function=target['truth_function'],
-            config=truth_config)
-
-    mixture['class_count'] = get_class_count(
-        truth_index=target['truth_index'],
-        truth=truth,
-        class_weights_threshold=class_weights_threshold)
-
     mixture['samples'] = len(augmented_target_audio)
     mixture['target_gain'] = target_gain
 
+    gain_adjusted_target_audio = np.int16(np.single(augmented_target_audio) * mixture['target_snr_gain'])
+    gain_adjusted_noise_audio = np.int16(np.single(noise_segment) * mixture['noise_snr_gain'])
+    generate_truth(mixdb=genmixdb_global['mixdb'],
+                   record=mixture,
+                   target=gain_adjusted_target_audio,
+                   noise=gain_adjusted_noise_audio)
+
     return mixture
 
 
@@ -712,7 +704,8 @@ def main():
         verbose = args['--verbose']
 
         for config_file in args['CONFIG']:
-            logger.info('Creating mixture database for {}'.format(config_file))
+            start_time = time.monotonic()
+            logger.info(f'Creating mixture database for {config_file}')
             config = get_config_from_file(config_file)
 
             base_name = get_base_name(config, config_file)
@@ -727,11 +720,14 @@ def main():
 
             with open(output_name, mode='w') as file:
                 json.dump(mixdb, file, indent=2)
-                logger.info('Wrote mixture database for {} to {}'.format(config_file, output_name))
+                logger.info(f'Wrote mixture database for {config_file} to {output_name}')
+
+            end_time = time.monotonic()
+            logger.info(f'Completed in {seconds_to_hms(seconds=end_time - start_time)}')
 
     except KeyboardInterrupt:
         logger.info('Canceled due to keyboard interrupt')
-        exit()
+        raise SystemExit(0)
 
 
 if __name__ == '__main__':
