@@ -58,6 +58,7 @@ import yaml
 from docopt import docopt
 
 import sonusai
+from sonusai import SonusAIError
 from sonusai import create_file_handler
 from sonusai import initial_log_messages
 from sonusai import logger
@@ -77,17 +78,17 @@ def gentcst(fold: str = '*',
         logger.info('Updating tree with JSON metadata')
         logger.info('')
 
-    logger.debug('fold:         {}'.format(fold))
-    logger.debug('ontology:     {}'.format(ontology))
-    logger.debug('hierarchical: {}'.format(hierarchical))
-    logger.debug('update:       {}'.format(update))
+    logger.debug(f'fold:         {fold}')
+    logger.debug(f'ontology:     {ontology}')
+    logger.debug(f'hierarchical: {hierarchical}')
+    logger.debug(f'update:       {update}')
     logger.debug('')
 
     config = get_config('config.yml')
 
     if config['truth_mode'] == 'mutex' and hierarchical:
-        logger.error('Multi-class truth is incompatible with truth_mode mutex')
-        exit()
+        logger.exception('Multi-class truth is incompatible with truth_mode mutex')
+        raise SonusAIError
 
     all_files = get_all_files(hierarchical)
     all_folds = get_folds_from_files(all_files)
@@ -100,7 +101,7 @@ def gentcst(fold: str = '*',
     labels = get_labels_from_files(all_files)
     logger.debug('Truth indices:')
     for item in labels:
-        logger.debug(' {:3} {}'.format(item['index'], item['display_name']))
+        logger.debug(f' {item["index"]:3} {item["display_name"]}')
     logger.debug('')
 
     gen_truth_indices(use_files, labels)
@@ -111,7 +112,7 @@ def gentcst(fold: str = '*',
 
     config['targets'] = []
 
-    logger.info('gentcst {} entries in tree'.format(len(use_files)))
+    logger.info(f'gentcst {len(use_files)} entries in tree')
     for file in use_files:
         local_config = {}
         local_name = dirname(file['file']) + '/config.yml'
@@ -129,8 +130,8 @@ def gentcst(fold: str = '*',
 
         if 'feature' in local_config.keys():
             if config['feature'] != local_config['feature']:
-                logger.warning('Local feature for {} ({}) is not the same as top level ({})'.format(
-                    file['file'], local_config['feature'], config['feature']))
+                logger.warning(
+                    f'Local feature for {file["file"]} ({local_config["feature"]}) is not the same as top level ({config["feature"]})')
 
         target = {'target_name': file['file'], 'truth_index': file['truth_index']}
         if 'truth_function' in local_config.keys():
@@ -219,11 +220,11 @@ def get_use_folds(all_folds: list, fold: str) -> list:
     use_folds = list(set(req_folds).intersection(all_folds))
 
     logger.debug('Fold information')
-    logger.debug(' Available: {}'.format(all_folds))
-    logger.debug(' Requested: {}'.format(req_folds))
-    logger.debug(' Used:      {}'.format(use_folds))
-    logger.debug(' Unused:    {}'.format(list(set(use_folds).symmetric_difference(all_folds))))
-    logger.debug(' Missing:   {}'.format(list(np.setdiff1d(req_folds, all_folds))))
+    logger.debug(f' Available: {all_folds}')
+    logger.debug(f' Requested: {req_folds}')
+    logger.debug(f' Used:      {use_folds}')
+    logger.debug(f' Unused:    {list(set(use_folds).symmetric_difference(all_folds))}')
+    logger.debug(f' Missing:   {list(np.setdiff1d(req_folds, all_folds))}')
     logger.debug('')
 
     return use_folds
@@ -252,8 +253,8 @@ def get_name_from_id(ontology_data: list, identity: str) -> list:
     for item in ontology_data:
         if item['id'] == identity:
             if found:
-                logger.error('id {} appears multiple times in ontology'.format(identity))
-                exit()
+                logger.exception(f'id {identity} appears multiple times in ontology')
+                raise SonusAIError
 
             name = item['name']
             found = True
@@ -268,8 +269,8 @@ def get_id_from_name(ontology_data: list, name: str) -> str:
     for item in ontology_data:
         if name in item['name']:
             if found:
-                logger.error('name {} appears multiple times in ontology'.format(name))
-                exit()
+                logger.exception(f'name {name} appears multiple times in ontology')
+                raise SonusAIError
 
             identity = item['id']
             found = True
@@ -312,12 +313,12 @@ def validate_class(ontology_data: list, file: dict) -> bool:
 
     for c in classes:
         if not is_valid_name(ontology_data, c):
-            logger.warning(' Could not find {} in ontology for {}'.format(c, file['file']))
+            logger.warning(f' Could not find {c} in ontology for {file["file"]}')
             valid = False
 
     if valid:
         if not is_valid_hierarchy(ontology_data, classes):
-            logger.warning(' Invalid parent/child relationship for {}'.format(file['file']))
+            logger.warning(f' Invalid parent/child relationship for {file["file"]}')
             valid = False
 
     return valid
@@ -394,31 +395,31 @@ def get_index_from_label(labels: list, label: str) -> int:
 
 def get_config(config_name: str) -> dict:
     if not exists(config_name):
-        logger.error('No confg.yml at top level')
-        exit()
+        logger.exception('No confg.yml at top level')
+        raise SonusAIError
 
     with open(config_name, mode='r') as yaml_file:
         config = yaml.safe_load(yaml_file)
 
     if 'feature' not in config.keys():
-        logger.error('feature not in top level config')
-        exit()
+        logger.exception('feature not in top level config')
+        raise SonusAIError
 
     if 'truth_function' not in config.keys():
-        logger.error('truth_function not in top level config')
-        exit()
+        logger.exception('truth_function not in top level config')
+        raise SonusAIError
 
     if 'truth_config' not in config.keys():
-        logger.error('truth_config not in top level config')
-        exit()
+        logger.exception('truth_config not in top level config')
+        raise SonusAIError
 
     if 'truth_mode' not in config.keys():
-        logger.error('truth_mode not in top level config')
-        exit()
+        logger.exception('truth_mode not in top level config')
+        raise SonusAIError
 
     if config['truth_mode'] not in ['normal', 'mutex']:
-        logger.error('Invalid truth_mode in top level config')
-        exit()
+        logger.exception('Invalid truth_mode in top level config')
+        raise SonusAIError
 
     return config
 
@@ -426,7 +427,7 @@ def get_config(config_name: str) -> dict:
 def validate_ontology(ontology: str, files: list) -> list:
     if exists(ontology):
         ontology_data = get_ontology(ontology)
-        logger.debug('Reference ontology in {} has {} classes'.format(ontology, len(ontology_data)))
+        logger.debug(f'Reference ontology in {ontology} has {len(ontology_data)} classes')
         logger.debug('')
 
         logger.info('Checking tree against reference ontology')
@@ -459,9 +460,9 @@ def get_node_from_name(ontology_data: list, name: str) -> dict:
         return nodes[0]
 
     if nodes:
-        logger.warning('Found multiple entries in reference ontology that match {}'.format(name))
+        logger.warning(f'Found multiple entries in reference ontology that match {name}')
     else:
-        logger.warning('Could not find entry for {} in reference ontology'.format(name))
+        logger.warning(f'Could not find entry for {name} in reference ontology')
 
     return {}
 
@@ -489,14 +490,14 @@ def report_leaf_fold_data_usage(all_files: list, use_files: list):
     leaf_len = len(max(all_leaves, key=len))
     for leaf in all_leaves:
         folds = get_folds_from_leaf(all_files, leaf)
-        logger.debug(' {:{}} {}'.format(leaf, leaf_len, folds))
+        logger.debug(f' {leaf:{leaf_len}} {folds}')
     logger.debug('')
 
     dif_leaves = set(all_leaves).symmetric_difference(use_leaves)
     if dif_leaves:
         logger.warning('This fold selection is missing data from the following leaves')
         for c in dif_leaves:
-            logger.warning(' {}'.format(c))
+            logger.warning(f' {c}')
         logger.warning('')
 
 
@@ -526,7 +527,7 @@ def main():
 
         with open(output_name, 'w') as yaml_file:
             yaml.dump(config, yaml_file)
-            logger.info('Wrote config to {}'.format(output_name))
+            logger.info(f'Wrote config to {output_name}')
 
         csv_fields = ['index', 'display_name']
         csv_name = splitext(output_name)[0] + '.csv'
@@ -535,11 +536,11 @@ def main():
             writer = csv.DictWriter(csv_file, fieldnames=csv_fields)
             writer.writeheader()
             writer.writerows(labels)
-            logger.info('Wrote labels to {}'.format(csv_name))
+            logger.info(f'Wrote labels to {csv_name}')
 
     except KeyboardInterrupt:
         logger.info('Canceled due to keyboard interrupt')
-        exit()
+        raise SystemExit(0)
 
 
 if __name__ == '__main__':
