@@ -1,5 +1,6 @@
 import numpy as np
 
+from sonusai import SonusAIError
 from sonusai import logger
 
 
@@ -17,8 +18,8 @@ def calculate_metrics(cmall: np.ndarray, binary_mode: bool = True) -> (np.ndarra
     # cmsum    num_classes x num_classes   Sum of all sum counts
 
     if cmall.shape[-1] != cmall.shape[-2]:
-        logger.error('Confusion matrix must be a square matrix.')
-        exit()
+        logger.exception('Confusion matrix must be a square matrix.')
+        raise SonusAIError
 
     num_classes = cmall.shape[-1]
     ndimsum = np.ndim(cmall) - 2
