@@ -14,16 +14,15 @@ def confusion_matrix_to_string(cm: np.ndarray, normalize: bool = False) -> str:
 
     result = ''
     if not normalize:
-        result += 'Confusion matrix with num_classes, total count: {},{}:\n'.format(num_classes, total_count)
+        result += f'Confusion matrix with num_classes, total count: {num_classes},{total_count}:\n'
         with np.printoptions(suppress=True):
-            result += '{}\n'.format(cm.astype(int))
+            result += f'{cm.astype(int)}\n'
     else:
         eps = np.finfo(float).eps
         norm_val = (np.tile(np.reshape(row_count, (num_classes, 1)), (1, num_classes)) + eps)
         ncm = cm / norm_val  # element by element
-        result += 'Normalized confusion matrix (%) with num_classes, total count: {},{}:\n'.format(num_classes,
-                                                                                                   total_count)
+        result += f'Normalized confusion matrix (%) with num_classes, total count: {num_classes},{total_count}:\n'
         with np.printoptions(precision=2, suppress=True):
-            result += '{}\n'.format(np.round(ncm * 100, 0).astype(int))
+            result += f'{np.round(ncm * 100, 0).astype(int)}\n'
 
     return result
