@@ -5,5 +5,4 @@ import numpy as np
 
 def format_confusion_matrix(cm: np.ndarray, labels: List[str] = None) -> str:
     # print confusion matrix from float variable cm and optional labels list
-    result = '{}\n'.format(cm.astype(int))
-    return result
+    return f'{cm.astype(int)}\n'
