@@ -22,7 +22,7 @@ def generate_snr_summary(mstat: np.ndarray, smetrics: np.ndarray, snrfloat: List
     NMIX = NNF * NTF * NSNR * NAUG
     num_classes = smetrics.shape[1]
 
-    result = '--- NN Performance over {} mixtures per Global SNR ---\n'.format(NMIX / NSNR)
+    result = f'--- NN Performance over {NMIX / NSNR} mixtures per Global SNR ---\n'
     result += '| SNR |  PPV% |  TPR% |  F1%  |  FPR% |  ACC% | SgSNRavg | SgSNR80p |\n'
     for si in range(NSNR):
         snri = tasnridx[si]
@@ -32,17 +32,17 @@ def generate_snr_summary(mstat: np.ndarray, smetrics: np.ndarray, snrfloat: List
         segsnr80pc = np.mean(mstat[:, :, snri, :, 4][tmpif])  # segmsnr80pc, unweighted avg, ignoring nans
         metavg = averages(smetrics[snri,])  # multiclass uses class averages
         # metavg fields: [PPV, TPR, F1, FPR, ACC, TPSUM]
-        result += '| {:+3.0f} | {:5.1f} | {:5.1f} | {:5.1f} | {:5.1f} | {:5.1f} |   {:+3.0f}    |   {:+3.0f}    |\n'.format(
-            max(min(round(mstat[0, 0, snri, 0, 1]), 99), -99),  # target snr, should be same all mixtures
-            metavg[0, 0] * 100,  # PPV macro avg
-            metavg[0, 1] * 100,  # TPR macro avg
-            metavg[0, 2] * 100,  # F1 macro avg
-            metavg[1, 3] * 100,  # FPR micro avg
-            metavg[1, 4] * 100,  # ACC micro-avg = F1 micro-avg = PPV micro-avg = TPR micro-avg
-            max(min(round(mssnravg), 99), -99),  # mean segsnr avg over mixtures
-            max(min(round(segsnr80pc), 99), -99))  # segsnr 80th percentile avg over mixutres
+        result += f'| {max(min(round(mstat[0, 0, snri, 0, 1]), 99), -99):+3.0f} '
+        result += f'| {metavg[0, 0] * 100:5.1f} '
+        result += f'| {metavg[0, 1] * 100:5.1f} '
+        result += f'| {metavg[0, 2] * 100:5.1f} '
+        result += f'| {metavg[1, 3] * 100:5.1f} '
+        result += f'| {metavg[1, 4] * 100:5.1f} '
+        result += f'|   {max(min(round(mssnravg), 99), -99):+3.0f}    '
+        result += f'|   {max(min(round(segsnr80pc), 99), -99):+3.0f}    '
+        result += f'|\n'
 
     if num_classes > 1:
-        result += 'PPV,TPR,F1 are macro-avg, FPR, ACC are micro-avg over {:>6} classes.\n'.format(num_classes)
+        result += f'PPV,TPR,F1 are macro-avg, FPR, ACC are micro-avg over {num_classes:>6} classes.\n'
 
     return result
