@@ -1,5 +1,6 @@
 from typing import List
 
+from sonusai import SonusAIError
 from sonusai import logger
 
 
@@ -8,6 +9,6 @@ def get_class_weights_threshold(mixdb: dict) -> List[float]:
     if not isinstance(class_weights_threshold, list):
         class_weights_threshold = [class_weights_threshold] * mixdb['num_classes']
     if len(class_weights_threshold) != mixdb['num_classes']:
-        logger.error('invalid class_weights_threshold length: {}'.format(len(class_weights_threshold)))
-        exit()
+        logger.error(f'invalid class_weights_threshold length: {len(class_weights_threshold)}')
+        raise SonusAIError
     return class_weights_threshold
