@@ -1,6 +1,7 @@
 import yaml
 
 import sonusai
+from sonusai import SonusAIError
 from sonusai import logger
 
 
@@ -11,8 +12,8 @@ def get_default_config() -> dict:
             config = yaml.safe_load(file)
         return config
     except Exception as e:
-        logger.error('Error loading genmixdb default config: {}'.format(e))
-        exit()
+        logger.exception(f'Error loading genmixdb default config: {e}')
+        raise SonusAIError
 
 
 def get_config_from_file(config_name: str) -> dict:
@@ -30,5 +31,5 @@ def get_config_from_file(config_name: str) -> dict:
 
         return config
     except Exception as e:
-        logger.error('Error preparing genmixdb config: {}'.format(e))
-        exit()
+        logger.exception(f'Error preparing genmixdb config: {e}')
+        raise SonusAIError
