@@ -5,7 +5,7 @@ from typing import Union
 def get_mixtures_from_mixid(mix_in: list, mixid: Union[str, List[int]]) -> list:
     if isinstance(mixid, str):
         try:
-            mix_out = eval("mix_in[{}]".format(mixid))
+            mix_out = eval(f'mix_in[{mixid}]')
             if not isinstance(mix_out, list):
                 mix_out = [mix_out]
             return mix_out
