@@ -1,3 +1,4 @@
+from sonusai import SonusAIError
 from sonusai import logger
 
 
@@ -9,12 +10,12 @@ def get_offsets(mixdb: dict, mixid: int) -> (int, int, int):
     ]
     for key in required_keys:
         if key not in mixdb.keys():
-            logger.error('Missing {} in mixdb'.format(key))
-            exit()
+            logger.exception(f'Missing {key} in mixdb')
+            raise SonusAIError
 
     if mixid >= len(mixdb['mixtures']) or mixid < 0:
-        logger.error('Invalid mixid: {}'.format(mixid))
-        exit()
+        logger.exception(f'Invalid mixid: {mixid}')
+        raise SonusAIError
 
     i_sample_offset = sum([sub['samples'] for sub in mixdb['mixtures'][:mixid + 1]])
     i_frame_offset = i_sample_offset // mixdb['frame_size']
