@@ -15,7 +15,6 @@ import wave
 from os.path import splitext
 
 import h5py
-import numpy as np
 from docopt import docopt
 
 import sonusai
@@ -39,16 +38,16 @@ def mkwav(files: list, dry_run: bool = False, verbose: bool = False):
     for file in files:
         base_name = splitext(file)[0]
         if verbose:
-            logger.info('Processing {}'.format(file))
+            logger.info(f'Processing {file}')
         try:
             with h5py.File(file, 'r') as f:
                 keys = f.keys()
                 for audio_name in audio_names:
                     if audio_name in keys:
                         out_name = base_name + '_' + audio_name + '.wav'
-                        audio = np.array(f['/' + audio_name])
+                        audio = f['/' + audio_name][:]
                         if verbose:
-                            logger.info(' writing {} samples to {}'.format(len(audio), out_name))
+                            logger.info(f'Writing {len(audio)} samples to {out_name}')
                         if not dry_run:
                             with wave.open(out_name, 'w') as w:
                                 w.setnchannels(mixture.channel_count)
@@ -56,7 +55,7 @@ def mkwav(files: list, dry_run: bool = False, verbose: bool = False):
                                 w.setframerate(mixture.sample_rate)
                                 w.writeframesraw(audio)
         except Exception as e:
-            logger.error('Error processing {}: {}'.format(file, e))
+            logger.error(f'Error processing {file}: {e}')
 
 
 def main():
@@ -74,7 +73,7 @@ def main():
 
     except KeyboardInterrupt:
         logger.info('Canceled due to keyboard interrupt')
-        exit()
+        raise SystemExit(0)
 
 
 if __name__ == '__main__':
