@@ -26,6 +26,7 @@ from subprocess import run
 from docopt import docopt
 
 import sonusai
+from sonusai import SonusAIError
 from sonusai import create_file_handler
 from sonusai import initial_log_messages
 from sonusai import logger
@@ -48,19 +49,18 @@ def predict(model: str,
 
     # create output directory
     if output is None:
-        now = datetime.now()
-        output = 'predict-{:%Y%m%d-%H%M%S}'.format(now)
+        output = f'predict-{datetime.now():%Y%m%d-%H%M%S}'
 
     try:
         mkdir(output)
-    except OSError as error:
-        logger.error('Could not create directory, {}: {}'.format(output, error))
-        exit()
+    except OSError as e:
+        logger.exception(f'Could not create directory, {output}: {e}')
+        raise SonusAIError
 
     log_name = output + '/predict.log'
     create_file_handler(log_name)
 
-    logger.info('Writing results to {}'.format(output))
+    logger.info(f'Writing results to {output}')
 
     # create command
     predict_type = ''
@@ -90,8 +90,8 @@ def predict(model: str,
     try:
         run(command, check=True)
     except Exception as e:
-        logger.error('Error running predict: {}'.format(e))
-        exit()
+        logger.exception(f'Error running predict: {e}')
+        raise SonusAIError
 
 
 def main():
@@ -111,7 +111,7 @@ def main():
 
     except KeyboardInterrupt:
         logger.info('Canceled due to keyboard interrupt')
-        exit()
+        raise SystemExit(0)
 
 
 if __name__ == '__main__':
