@@ -1,5 +1,6 @@
 import numpy as np
 
+from sonusai import SonusAIError
 from sonusai import logger
 from sonusai.metrics import calculate_class_weights
 
@@ -33,12 +34,11 @@ def reshape_inputs(feature: np.ndarray, truth: np.ndarray, batch_size: int, time
     (frames, strides, bands) = f.shape
     (truth_frames, num_classes) = t.shape
     if frames != truth_frames:  # Double-check correctness of inputs
-        logger.error('Frames in feature and truth do not match')
-        exit()
+        logger.exception('Frames in feature and truth do not match')
+        raise SonusAIError
 
-    msg = 'Training/truth shape: {}x{}x{}, nclass/outlen = {}\n'.format(frames, strides, bands, num_classes)
-    msg += 'Reshape request: timesteps {}, batchsize {}, flatten={}, add1ch={}\n'.format(
-        timesteps, batch_size, flatten, add1ch)
+    msg = f'Training/truth shape: {frames}x{strides}x{bands}, nclass/outlen = {num_classes}\n'
+    msg += f'Reshape request: timesteps {timesteps}, batchsize {batch_size}, flatten={flatten}, add1ch={add1ch}\n'
 
     # Compute class weights by hand as sklearn does not handle non-existent classes
     cweights = calculate_class_weights(t)
@@ -59,7 +59,7 @@ def reshape_inputs(feature: np.ndarray, truth: np.ndarray, batch_size: int, time
         return f, t, in_shape, num_classes, cweights, msg  # quick
 
     if flatten:
-        msg += 'Flattening {}x{} feature to {}\n'.format(strides, bands, strides * bands)
+        msg += f'Flattening {strides}x{bands} feature to {strides * bands}\n'
         f = np.reshape(f, (frames, strides * bands))
 
     # Reshape for Keras/TF recurrent models that require timesteps/sequence length dimension
@@ -73,7 +73,7 @@ def reshape_inputs(feature: np.ndarray, truth: np.ndarray, batch_size: int, time
         sequences = sequences - brem
         fr2drop = frem + bfrem
         if fr2drop:
-            msg += 'Dropping {} frames for new number of sequences to fit in multiple of batch_size\n'.format(fr2drop)
+            msg += f'Dropping {fr2drop} frames for new number of sequences to fit in multiple of batch_size\n'
             if f.ndim == 2:
                 f = f[0:-fr2drop, ]  # Flattened input
             elif f.ndim == 3:
@@ -82,7 +82,7 @@ def reshape_inputs(feature: np.ndarray, truth: np.ndarray, batch_size: int, time
             t = t[0:-fr2drop, ]
 
         # Do the reshape
-        msg += 'Reshape for timesteps = {}, new number of sequences (batches) = {}\n'.format(timesteps, sequences)
+        msg += f'Reshape for timesteps = {timesteps}, new number of sequences (batches) = {sequences}\n'
         if f.ndim == 2:  # Flattened input
             # str=str+'Reshaping 2 dim\n'
             f = np.reshape(f, (sequences, timesteps, strides * bands))  # was frames x bands*timesteps
@@ -95,7 +95,7 @@ def reshape_inputs(feature: np.ndarray, truth: np.ndarray, batch_size: int, time
         # Drop frames if remainder, not fitting into a multiple of new # sequences (Keras req)
         fr2drop = f.shape[0] % batch_size
         if fr2drop > 0:
-            msg += 'Dropping {} frames for total to be a multiple of batch_size\n'.format(fr2drop)
+            msg += f'Dropping {fr2drop} frames for total to be a multiple of batch_size\n'
             f = f[0:-fr2drop, ]
             t = t[0:-fr2drop, ]
 
@@ -107,8 +107,8 @@ def reshape_inputs(feature: np.ndarray, truth: np.ndarray, batch_size: int, time
     in_shape = f.shape
     in_shape = in_shape[1:]  # remove frame dim size
 
-    msg += 'Feature final shape: {}\n'.format(f.shape)
-    msg += 'Input shape final (includes timesteps): {}\n'.format(in_shape)
-    msg += 'Truth final shape: {}\n'.format(t.shape)
+    msg += f'Feature final shape: {f.shape}\n'
+    msg += f'Input shape final (includes timesteps): {in_shape}\n'
+    msg += f'Truth final shape: {t.shape}\n'
 
     return f, t, in_shape, num_classes, cweights, msg
