@@ -3,4 +3,4 @@ def seconds_to_hms(seconds: float) -> str:
     s = seconds - h * 3600
     m = int(s / 60)
     s = int(seconds - h * 3600 - m * 60)
-    return '{:d}:{:02d}:{:02d} (H:MM:SS)'.format(h, m, s)
+    return f'{h:d}:{m:02d}:{s:02d} (H:MM:SS)'
